==> mir_0.1.8+14.04.20140411.orig.tar.gz: mir-0.1.8+14.04.20140411/src/server/scene/surface_stack_model.h <==
/*
 * Copyright © 2012-2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Thomas Voss <thomas.voss@canonical.com>
 */

#ifndef MIR_SCENE_SURFACE_STACK_MODEL_H_
#define MIR_SCENE_SURFACE_STACK_MODEL_H_

#include "mir/frontend/surface_id.h"
#include "mir/scene/depth_id.h"
#include "mir/input/input_reception_mode.h"

#include <memory>

namespace mir
{
namespace frontend { class EventSink; }
namespace shell
{
struct SurfaceCreationParameters;
}

namespace scene
{

class Surface;

class SurfaceStackModel
{
public:
    virtual ~SurfaceStackModel() {}

    virtual void add_surface(
        std::shared_ptr<Surface> const& surface,
        DepthId depth,
        input::InputReceptionMode input_mode) = 0;

    virtual void remove_surface(std::weak_ptr<Surface> const& surface) = 0;

    virtual void raise(std::weak_ptr<Surface> const& surface) = 0;

protected:
    SurfaceStackModel() = default;
    SurfaceStackModel(const SurfaceStackModel&) = delete;
    SurfaceStackModel& operator=(const SurfaceStackModel&) = delete;
};

}
}

#endif // MIR_SCENE_SURFACE_STACK_MODEL_H_

==> mir_0.17.0+15.10.20151008.2.orig.tar.gz: mir-0.17.0+15.10.20151008.2/src/server/scene/surface_stack_model.h <==
/*
 * Copyright © 2012-2014 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Thomas Voss <thomas.voss@canonical.com>
 */

#ifndef MIR_SCENE_SURFACE_STACK_MODEL_H_
#define MIR_SCENE_SURFACE_STACK_MODEL_H_

#include "mir/frontend/surface_id.h"
#include "mir/scene/depth_id.h"
#include "mir/input/input_reception_mode.h"

#include <memory>
#include <set>

namespace mir
{
namespace geometry { class Point; }

namespace scene
{
class Surface;

class SurfaceStackModel
{
public:
    using SurfaceSet = std::set<std::weak_ptr<Surface>, std::owner_less<std::weak_ptr<Surface>>>;

    virtual ~SurfaceStackModel() = default;

    virtual void add_surface(
        std::shared_ptr<Surface> const& surface,
        DepthId depth,
        input::InputReceptionMode input_mode) = 0;

    virtual void remove_surface(std::weak_ptr<Surface> const& surface) = 0;

    virtual void raise(std::weak_ptr<Surface> const& surface) = 0;

    virtual void raise(SurfaceSet const& surfaces) = 0;

    virtual auto surface_at(geometry::Point) const -> std::shared_ptr<Surface> = 0;

protected:
    SurfaceStackModel() = default;
    SurfaceStackModel(const SurfaceStackModel&) = delete;
    SurfaceStackModel& operator=(const SurfaceStackModel&) = delete;
};

}
}

#endif // MIR_SCENE_SURFACE_STACK_MODEL_H_
